==> haskell-mod-0.2.0.1-120-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mod
version:              0.2.0.1
visibility:           public
id:                   mod-0.2.0.1-3Z0DGy7mVldKYFIupLwfxR
key:                  mod-0.2.0.1-3Z0DGy7mVldKYFIupLwfxR
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  57bf2c582de006a3e39c79ed134062f2
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mod-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mod-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mod-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.0.1-3Z0DGy7mVldKYFIupLwfxR
depends:
    base-4.17.2.1 deepseq-1.4.8.0 ghc-bignum-1.3
    primitive-0.9.0.0-1uQl5SMm5FQ52SaicTkt1Y
    semirings-0.7-Ft3nfOtlJKy9Wuf822xTTT
    vector-0.13.2.0-G0g5gCprguQ6M58H7uQE53

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mod-0.2.0.1-121-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mod.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mod
version:              0.2.0.1
visibility:           public
id:                   mod-0.2.0.1-DE0iwn6dBPrL6kkpH77dT4
key:                  mod-0.2.0.1-DE0iwn6dBPrL6kkpH77dT4
license:              MIT
copyright:            2017-2022 Andrew Lelechenko
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:               Andrew Lelechenko <andrew.lelechenko@gmail.com>
homepage:             https://github.com/Bodigrim/mod
synopsis:             Fast type-safe modular arithmetic
description:
    <https://en.wikipedia.org/wiki/Modular_arithmetic Modular arithmetic>,
    promoting moduli to the type level, with an emphasis on performance.
    Originally part of the <https://hackage.haskell.org/package/arithmoi arithmoi> package.

category:             Math, Number Theory
abi:                  adb5cec747d4eb45ad6ff09c1fb97281
exposed:              True
exposed-modules:      Data.Mod Data.Mod.Word
hidden-modules:       Data.Mod.Compat
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mod-0.2.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mod-0.2.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mod-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mod
hs-libraries:         HSmod-0.2.0.1-DE0iwn6dBPrL6kkpH77dT4
depends:
    base-4.17.2.1 deepseq-1.4.8.0 ghc-bignum-1.3
    primitive-0.9.0.0-AqOaxoERoHJDqDj73ogtnE
    semirings-0.7-ChWQMaHl3FOGxHylBKpUTL
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf

haddock-interfaces:   /usr/share/doc/haskell-mod/html/mod.haddock
haddock-html:         /usr/share/doc/haskell-mod/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
